<?php
/***************************************************************************************************************************************************
Plugin Name:  Page Columnist
Plugin URI: http://www.code-styling.de/english/development/wordpress-plugin-page-columnist-en
Description:  You can change the behavior of pagination inside WordPress pages by your demands. Paged Pages can be handled as simple single page while the page parts will be automatic converted into columns.
Author: Heiko Rabe
Author URI: http://www.code-styling.de/
Version: 1.1.8
***************************************************************************************************************************************************
 License:
 =======
 Copyright 2009 Heiko Rabe  (email : info@code-styling.de)

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
****************************************************************************************************************************************************/

//avoid direct calls to this file, because now WP core and framework has been used
if (!function_exists ('add_action')) {
		header('Status: 403 Forbidden');
		header('HTTP/1.1 403 Forbidden');
		exit();
}

//WordPress definitions
if ( !defined('WP_CONTENT_URL') )
	define('WP_CONTENT_URL', get_option('siteurl') . '/wp-content');
if ( !defined('WP_CONTENT_DIR') )
	define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
if ( !defined('WP_PLUGIN_URL') ) 
	define('WP_PLUGIN_URL', WP_CONTENT_URL.'/plugins');
if ( !defined('WP_PLUGIN_DIR') ) 
	define('WP_PLUGIN_DIR', WP_CONTENT_DIR.'/plugins');
if ( !defined('PLUGINDIR') )
	define( 'PLUGINDIR', 'wp-content/plugins' ); // Relative to ABSPATH.  For back compat.
	
if ( !defined('WP_LANG_DIR') )
	define('WP_LANG_DIR', WP_CONTENT_DIR . '/languages');

	
class Page_columnist_page_transition {

	function Page_columnist_page_transition(&$plugin, $page_id = false) {
		$this->plugin 		= $plugin; //reference to owner plugin
		$this->transition 	= $this->plugin->page_default_trans;
		$this->data			= array();
		if ($page_id) $this->load($page_id);
		else $this->page_id = 0;
	}

	function load($page_id) {
		$this->page_id		= ($page_id ? $page_id : 0);		
		$this->transition 	= $this->plugin->page_default_trans;
		$this->data			= array();
		$res = explode('|', get_post_meta($this->page_id, '_cspc-page-transitions', true));	
		$num = count($res);
		if ($num > 0) {
			if (in_array($res[0], array_keys($this->plugin->page_transitions))) {
				$this->transition = $res[0];
				if ($num > 1) {
					$this->data = unserialize($res[1]);
				}
			}
		}
	}
	
	function save() {
		if ($this->page_id > 0) {
			$value = $this->transition.'|'.serialize($this->data);
			update_post_meta($this->page_id, '_cspc-page-transitions', $value);
		}
	}
	
	function change($transition, $data = false) {
		if (in_array($transition, array_keys($this->plugin->page_transitions))) {
			if ($this->transition != $transition) {
				$this->transition = $transition;
			}
			if (is_array($data)) {
				$this->data = $data;
			}
			return true;
		}
		return false;
	}
	
	function spacing() {
		return (isset($this->data['spacing']) ? $this->data['spacing'] : $this->plugin->options->spacing);
	}
	
}


//page_columnist Plugin class	
class Plugin_page_columnist {
	
	//initializes the whole plugin and enables the activation/deactivation handling
	function Plugin_page_columnist() {
		global $wp_version;
		
		//own plugin data
		$this->basename 							= plugin_basename(__FILE__);
		$this->url									= WP_PLUGIN_URL.'/'.dirname($this->basename);
		$this->textdomain 							= basename($this->basename);
		$this->textdomain							= substr($this->textdomain, 0, strrpos($this->textdomain, '.'));
		$this->versions								= new stdClass;
		$this->versions->required					= array( 'php' => '4.4.2', 'wp' => '2.7');
		$this->versions->found						= array( 'php' => phpversion(), 'wp' => $wp_version);

		$this->page_default_trans 					= 'cspc-trans-wordpress';
		
		$this->defaults								= new stdClass;
		$this->defaults->spacing					= 3.0;
		$this->defaults->preview_assistent			= false;
		
		$this->options								= get_option('cspc_page_columnist', $this->defaults);
		$stored = get_object_vars($this->options);
		$defaults = get_object_vars($this->defaults);
		foreach($defaults as $key => $value) {
			if (!isset($stored[$key])) $this->options->$key = $value;
		}
									
		add_action('init', 							array(&$this, 'on_init'));
		add_action('admin_init',					array(&$this, 'on_admin_init'));
		add_action('wp_head',						array(&$this, 'on_wp_head'));
		add_action('admin_head', 					array(&$this, 'on_admin_head'));
		add_action('edit_page_form',				array(&$this, 'on_edit_page_form'));
		add_action('manage_pages_custom_column',	array(&$this, 'on_manage_pages_custom_column'), 10, 2);
		add_action('wp_insert_post', 				array(&$this, 'on_wp_insert_post'), 10, 2);
		add_action('loop_start', 					array(&$this, 'on_loop_start'));
		add_action('template_redirect',				array(&$this, 'on_template_redirect'));
		add_filter('mce_buttons',					array(&$this, 'on_filter_mce_buttons'));

		register_activation_hook($this->plugin->basename, array(&$this, 'on_activate_plugin'));
		register_deactivation_hook($this->plugin->basename, array(&$this, 'on_deactivate_plugin'));
		
		$this->_display_version_errors();
		
		//TODO:  future development should be able to deal with removing the ugly wpautop algorithm
		//remove_filter('the_content', 'wpautop');
	}

	function _get_version_errors() {
		$res = array();
		foreach($this->versions->required as $key => $value) {
			if (!version_compare($this->versions->found[$key], $value, '>=')) {
				$res[strtoupper($key).' Version'] = array('required' => $value, 'found' =>  $this->versions->found[$key]);
			}
		}
		return $res;
	}
	
	function _display_version_errors() {
		if (($_GET['action'] == 'error_scrape') && ($_GET['plugin'] == $this->basename )) {
			$version_error = $this->_get_version_errors();
			if (count($version_error) != 0) {
				echo "<table>";
				echo "<tr style=\"font-size: 12px;\"><td><strong style=\"border-bottom: 1px solid #000;\">Plugin can not be activated.</strong></td><td> | required</td><td> | actual</td></tr>";			
				foreach($version_error as $key => $value) {
					echo "<tr style=\"font-size: 12px;\"><td>$key</td><td align=\"center\"> &gt;= <strong>".$value['required']."</strong></td><td align=\"center\"><span style=\"color:#f00;\">".$value['found']."</span></td></tr>";
				}
				echo "</table>";
			}
		}
	}	
		
	//do all checks during plugin activation
	function on_activate_plugin() {
		$version_error = $this->_get_version_errors();
		if (count($version_error) != 0) {
			$current = get_option('active_plugins');
			array_splice($current, array_search($this->plugin->basename, $current), 1 );
			update_option('active_plugins', $current);
			exit();
		}
		if (!get_option('cspc_page_columnist'))
			update_options('cspc_page_columnist', get_option('cspc_page_columnist', $this->defaults));
	}
	
	//do cleanup operations on plugin deactivation
	function on_deactivate_plugin() {
		//TODO: cleanup the entries out of database
	}
	
	function setup_translation() {
		static $l10n_ready = false;
		if (!$this->l10n_ready) {
			$abs_rel_path = str_replace(ABSPATH, '', WP_PLUGIN_DIR.'/'.dirname($this->basename));
			$plugin_rel_path = dirname($this->basename);		
			load_plugin_textdomain($this->textdomain, $abs_rel_path, $plugin_rel_path);
			$this->l10n_ready = true;
		}
	}
	
	function is_MSIE() {
		return preg_match('/msie/i', $_SERVER['HTTP_USER_AGENT']) && !preg_match('/opera/i', $_SERVER['HTTP_USER_AGENT']);
	}
	
	function is_page_preview() {
		$id = (int)$_GET['preview_id'];
		$preview = $_GET['preview'];
		if ($id > 0 && $preview == 'true' && $this->options->preview_assistent) {
			global $wpdb;
			$type = $wpdb->get_results("SELECT post_type FROM $wpdb->posts WHERE ID=$id");
			if (count($type) && ($type[0]->post_type == 'page') && current_user_can('edit_page')) return true;
		}
		return false;
	}

	function is_page_overview() {
		global $pagenow;
		return (is_admin() && ($pagenow == 'edit-pages.php'));
	}

	function is_page_editor() {
		global $pagenow;
		return (is_admin() && ($pagenow == 'page.php'));
	}
	
	//gets called be action 'init' after wordpress core is up and running
	function on_init() {
		
		//ensures the correct matching translation file gets loaded
		$this->setup_translation();				
		$this->page_types = array(
			'cspc-paged' => __('WordPress - Next Page (default)', $this->textdomain),
			'cspc-linear'	=> __('Ordinary Plain Page', $this->textdomain),
			'cspc-std-cols' => __('Every Sub Page as Column', $this->textdomain),
			'cspc-bottom-cols' => __('First Sub Page as Header', $this->textdomain),
			'cspc-top-cols' => __('Last Sub Page as Footer', $this->textdomain),
			'cspc-middle-cols' => __('Interior as Columns', $this->textdomain)
		);
		
		$this->page_transitions = array(
			'cspc-trans-wordpress' 		=> array('func' => array(&$this,'exec_trans_wordpress'), 'img-pos' =>   0, 'text' => __('WordPress - Next Page (default)', $this->textdomain), 'default' => true),
			'cspc-trans-ordinary'		=> array('func' => array(&$this,'exec_trans_ordinary'), 'img-pos' => -16, 'text' => __('Ordinary Plain Page', $this->textdomain)),
			'cspc-trans-columns'		=> array('func' => array(&$this,'exec_trans_columns'), 'img-pos' => -32, 'text' => __('Every Sub Page as Column', $this->textdomain)),
			'cspc-trans-header'			=> array('func' => array(&$this,'exec_trans_header'), 'img-pos' => -48, 'text' => __('First Sub Page as Header', $this->textdomain)),
			'cspc-trans-footer'			=> array('func' => array(&$this,'exec_trans_footer'), 'img-pos' => -64, 'text' => __('Last Sub Page as Footer', $this->textdomain)),
			'cspc-trans-interior'		=> array('func' => array(&$this,'exec_trans_interior'), 'img-pos' => -80, 'text' => __('Interior as Columns', $this->textdomain)),
		);
				
		if ($this->is_page_preview() && !defined('DOING_AJAX')) {
			wp_enqueue_script('jquery-spin', $this->url.'/jquery.spin.js', array('jquery'));
			wp_enqueue_script('cspc_page_columnist_assistance', $this->url.'/page-columnist-assistance.js', array('jquery', 'jquery-ui-draggable', 'jquery-spin'));
			wp_enqueue_style('cspc_page_columnist_assistance', $this->url.'/page-columnist-assistance.css');
		}		

		if(defined('DOING_AJAX')) {
			add_action('wp_ajax_cspc_save_changes', array(&$this, 'on_ajax_save_changes'));
		}
	}
	
	function on_admin_init() {

		if ($this->is_page_overview()) {
			add_filter('manage_edit-pages_columns', array(&$this,'on_filter_manage_edit_pages_columns'));
		}
		
		if ($this->is_page_editor()) {
			add_meta_box('cspc-page-transitions', __('Pagebreaks', $this->textdomain), array(&$this, 'on_print_metabox_content_cspc_page_transitions'), 'page', 'side', 'core');
			wp_enqueue_script('jquery-spin', $this->url.'/jquery.spin.js', array('jquery'));		
		}		
	}
	
	//gets called be action 'head' if the page head shold be printed
	function on_wp_head() {
		if ($this->is_page_preview()) {
			$pt = new Page_columnist_page_transition($this, (int)$_GET['preview_id']);			
		?>
		<script type="text/javascript">
		var cspc_page_columnist_l10n = {
			adminUrl: '<?php echo admin_url(); ?>',
			pageId: <?php echo (int)$_GET['preview_id']; ?>,
			imageBasePath: '<?php echo $this->url.'/img/'; ?>',
			spacing: <?php echo (int)$pt->spacing(); ?>,
			text: {
				expander: '<?php _e('Page Columnist &bull; Assistance', $this->textdomain); ?>',
				spacing: '<?php _e('% spacing', $this->textdomain); ?>',
				defaultspacing: '<?php _e('default spacing', $this->textdomain); ?>',
				save: '<?php _e('save changes', $this->textdomain); ?>',
				editing: '<?php _e('enable column editing', $this->textdomain); ?>',
				sizing: '<?php _e('enable column resizing', $this->textdomain); ?>',
				locking: '<?php _e('enable column locking', $this->textdomain); ?>'
			},
			widgets: {
				calendar: {
					text: '<?php _e('insert calendar widget', $this->textdomain); ?>'
				},
				stats: {
					text: '<?php _e('insert statistic widget', $this->textdomain); ?>'
				}
			}
		};
		</script>
		<?php }
	}
		
	//gets called by action 'admin_head'
	function on_admin_head() {
		if ($this->is_page_overview() || $this->is_page_editor()) :	?>
		<style type="text/css">
			#cspc-page-transition-col { width: 30px; } 
			.cspc-page-transition-row { width: 16px; height: 16px; }
			.cspc-page-transition-box { padding: 0px 3px 3px 18px; line-height: 18px; white-space: nowrap; }
			*:first-child + html #cspc-page-transitions input { margin-top: -3px; margin-left: 0xp;} /* IE fix */
			*:first-child + html #cspc-page-transitions p { margin: 3px; }
			#cspc-default-column-spacing { font-size:12px;vertical-align:top;width:26px;background-color:#fff;color:#000;height:19px; padding: 1px 0px 2px 1px; line-height:15px;} /* border: solid 1px #000; line-height:15px;}*/
			*:first-child + html #cspc-default-column-spacing, html:first-child>b\ody #cspc-default-column-spacing  { height: 15px; } /* IE and Opera */
			<?php foreach($this->page_transitions as $key => $val) : ?>
			.<?php echo $key; ?> { background: transparent url(<?php echo $this->url.'/states.png'; ?>) no-repeat left <?php echo $val['img-pos']; ?>px; }
			<?php endforeach; ?>
		</style>
			<?php if ($this->is_page_editor()) : ?>
			<script type="text/javascript">
				jQuery(document).ready(function(){
					jQuery('#cspc-default-column-spacing').spin({max:10,min:0,imageBasePath: '<?php echo $this->url.'/img/'; ?>', interval: 0.5 });
				});
			</script>
			<?php endif; ?>
		<?php endif;
	}

	//insert the nextpage button to TinyMCE button bar if it's not there
	function on_filter_mce_buttons($buttons) {
		if ($this->is_page_editor()) {
			if (!in_array('wp_page', $buttons)) {
				if (!in_array('wp_more', $buttons)) {
					$last = array_pop($buttons);
					$buttons[] = "wp_page";
					$buttons[] = $last;
				}else{
					$txt = implode('|', $buttons);
					$txt = str_replace('wp_more|','wp_more|wp_page|', $txt);
					$buttons = explode('|', $txt);
				}
			}
		}
		return $buttons;		
	}

	//insert nextpage button to HTML editor, if not present there
	function on_edit_page_form() {
		if ($this->is_page_editor()) : ?>
		<script type="text/javascript">
			//<![CDATA[
			jQuery(document).ready(function() {
				if (!jQuery("#ed_next").length) {
					content = '<input id="ed_next" class="ed_button" type="button" value="<?php _e('nextpage',$this->textdomain); ?>" title="<?php _e('insert Page break', $this->textdomain); ?>" onclick="edInsertContent(edCanvas, \'<!--nextpage-->\');" accesskey="t" />';
					jQuery("#ed_toolbar").append(content);
				}
			});
			//]]>
		</script>
		<?php endif;
	}
	
	//append a custom column at edit pages overview
	function on_filter_manage_edit_pages_columns($columns) {
		$columns['cspc-page-transition-col'] = __('PC', $this->textdomain);
		return $columns;
	}
	
	//add content to the aappended edit page overview column
	function on_manage_pages_custom_column($column_name, $id) {
		if ($column_name == 'cspc-page-transition-col') {
			$pt = new Page_columnist_page_transition($this, $id);
			echo "<div class=\"cspc-page-transition-row $pt->transition\">&nbsp;</div>";
		}
	}
	
	//save the page transition mode setting of page, if something has been saved
	function on_wp_insert_post($post_ID, $post) {
		if(!current_user_can('edit_page', $entry['ID'])) return;
		
		$my_id 		= ($_POST['wp-preview'] == 'dopreview' ? $_POST['post_ID'] : $post_ID);	
		$my_type 	= ($_POST['wp-preview'] == 'dopreview' ? $_POST['post_type'] : $post->post_type);
		
		if ($my_type == 'page') { 
		
			$pt = new Page_columnist_page_transition($this, $my_id);
			if ($pt->transition != $_POST['cspc-page-transition']){ 
				$pt->change($_POST['cspc-page-transition']);
			}
			$pt->save();
			
			$this->options->preview_assistent = (bool)$_POST['cspc-preview-assistent'];
			$this->options->spacing = (float)$_POST['cspc-default-column-spacing'];
			update_option('cspc_page_columnist', $this->options);
		}
	}
	
	function on_ajax_save_changes() {
		if (current_user_can('edit_page')) {
			$page_id = (int)$_POST['page_id'];
			$spacing = (float)$_POST['spacing'];
			$default_spacing = ($_POST['default_spacing'] == 'true' ? true : false);
			
			$pt = new Page_columnist_page_transition($this, $page_id);
			$pt->data['spacing'] = $spacing;
			$pt->save();
			
			if ($default_spacing) {
				$this->options->spacing = $spacing;
				update_option('cspc_page_columnist', $this->options);
			}
		}
		else{
			header('Status: 404 Not Found');
			header('HTTP/1.1 404 Not Found');
			_e('You do not have the permission to edit this page.', $this->textdomain);
		}
		exit();
	}
	
	
	//ouput the content of new one sidebar box at page editing
	function on_print_metabox_content_cspc_page_transitions($data) {
		$pt = new Page_columnist_page_transition($this, $data->ID);
		foreach($this->page_transitions as $type => $val) : ?>
			<p><input id="<?php echo $type; ?>" type="radio" name="cspc-page-transition" value="<?php echo $type; ?>" <?php if($type == $pt->transition) echo 'checked="checked"'; ?>/><label for="<?php echo $type; ?>" class="cspc-page-transition-box <?php echo $type; ?>"><?php echo $val['text']; ?></label></p>
		<?php endforeach; ?>
		<p style="margin-top:15px; border-top: dotted 1px #999; padding: 5px 0px;">
			<input id="cspc-default-column-spacing" name="cspc-default-column-spacing" type="text" value="<?php echo $this->options->spacing; ?>" readonly="readonly" autocomplete="off"/><label>&nbsp;&nbsp;<?php _e('% column default spacing', $this->textdomain); ?></label><br/>
			<input id="cspc-preview-assistent" name="cspc-preview-assistent" type="checkbox" <?php if($this->options->preview_assistent) echo 'checked="checked"'; ?>/><label for="cspc-preview-assistent">&nbsp;<?php _e('Page Columnist Assistance at Preview', $this->textdomain); ?></label>			
		</p>
		<?php /*
		<script>
		jQuery(document).ready( function() {
			jQuery('#cspc-assistent').click(function(){
				jQuery(this).blur();
				if (typeof tinyMCE == 'undefined' || !tinyMCE.activeEditor || tinyMCE.activeEditor.isHidden()) alert('TEXTAREA: '+jQuery('#content').val());
				else alert(tinyMCE.activeEditor.getContent());
				return false;
			});
		});
		</script>
		*/ ?>
		<?php		
	}

	function columnize_pages($num, $pages, &$r_pt) {
		$res = '';
		$base = 100.0;
		$spacing = $r_pt->spacing();
		if ($this->is_MSIE()) {
			//IE is not able to calculate column sizes well, several 100% sums leads to get the last column display wrapped under the first
			//in several cases (mostly where a periodic fraction of 1/3 or 1/6 occures) , IE seems to reach by internal rounding errors more than 100% of available width
			$base = $base - $spacing * 0.15; 
		}
		$perc = ($base - ($num - 1) * $spacing) / $num; 
		for ($i=0; $i<$num; $i++) {
			$page = $pages[$i];
			$margin_left_i = ($i==0 ? 0 : $spacing);
			$color = $this->colors[$i];
			$res .= "<div id=\"cspc-column-$i\" class=\"cspc-column\" style=\"float:left;margin-left:$margin_left_i%;width:$perc%;overflow:hidden;\">";
			if (has_filter('the_content', 'wpautop') && !preg_match('/^\s*<div/', $page)) $res .= '<p>';
			$res .= $page;
			if (has_filter('the_content', 'wpautop') && !preg_match('/<\/p>\s*$/', $page)) $res .= '</p>';
			$res .= '</div>';
		}
		return $res;		
	}
	
	function columnize_ordinary_page($page, $clearleft = false) {
		if (empty($page)) return '';
		$res = ($clearleft ? '<div id="cspc-footer" style="clear:left;">' : '<div id="cspc-header">');
		if (has_filter('the_content', 'wpautop') && !preg_match('/^\s*<div/', $page)) $res .= '<p>';
		$res .= $page;
		if (has_filter('the_content', 'wpautop') &&!preg_match('/<\/p>\s*$/', $page)) $res .= '</p>';
		$res .= '</div>';
		return $res;
	}
	
	function exec_trans_wordpress($pages, &$r_pt) {
		return $pages;
	}
	
	function exec_trans_ordinary($pages, &$r_pt) {
		$trans = $r_pt->transition;
		$res = "<div id=\"$trans-wrap\" class=\"cspc-wrapper\">";
		$res .= "\n\n";
		$res .= implode("\n\n", $pages);
		$res .='</div>';
		return array($res);
	}
	
	function exec_trans_columns($pages, &$r_pt) {
		$trans = $r_pt->transition;
		$num = count($pages);
		$res = "<div id=\"$trans-wrap\" class=\"cspc-wrapper\">";
		$res .= $this->columnize_pages($num, $pages, $r_pt);
		$res .= '<div style="clear:left;"></div></div>';
		return array($res);
	}
	
	function exec_trans_header($pages, &$r_pt) {
		$trans = $r_pt->transition;
		$top = array_shift($pages);
		$num = count($pages);
		$res = "<div id=\"$trans-wrap\" class=\"cspc-wrapper\">";
		$res .= $this->columnize_ordinary_page($top);
		$res .= $this->columnize_pages($num, $pages, $r_pt);
		$res .= '<div style="clear:left;"></div></div>';
		return array($res);
	}
	
	function exec_trans_footer($pages, &$r_pt) {
		$trans = $r_pt->transition;
		$last = end($pages);
		$num = count($pages) -1;
		$pages = ($num > 0 ? array_slice($pages,0,$num) : array());
		$res = "<div id=\"$trans-wrap\" class=\"cspc-wrapper\">";
		$res .= $this->columnize_pages($num, $pages, $r_pt);
		$res .= $this->columnize_ordinary_page($last, true);
		$res .= '</div>';
		return array($res);
	}
	
	function exec_trans_interior($pages, &$r_pt) {
		$trans = $r_pt->transition;
		$top = array_shift($pages);
		$num = count($pages) -1;
		$last = ($num > 0 ? end($pages) : '');
		$pages = ($num > 0 ? array_slice($pages,0,$num) : array());
		$res = "<div id=\"$trans-wrap\" class=\"cspc-wrapper\">";
		$res .= $this->columnize_ordinary_page($top);
		$res .= $this->columnize_pages($num, $pages, $r_pt);
		$res .= $this->columnize_ordinary_page($last, true);
		$res .= '</div>';
		return array($res);
	}
	
	function on_loop_start() {
		if (is_page()) {
			global $post, $id, $page, $pages, $multipage, $numpages;
			
			$pt = new Page_columnist_page_transition($this, $post->ID);
			if($pt->transition == $this->page_default_trans) return;
			$pages = call_user_func($this->page_transitions[$pt->transition]['func'], $pages, $pt);
			
			$multipage = 0;
			$numpages = 1;

/*			
			//TODO: future versions should check ugly invalid <p> based at shortcode api if possible
			if (has_filter('the_content', 'wpautop')) {
				preg_match('/'.get_shortcode_regex().'(\s\s|)/', $pages[0],$hits);
				var_dump($hits);
			}
*/		

		}
	}
	
	//if we are in none standard page mode, ensure a redirect to main page slug, if sub-page has been requested directly
	function on_template_redirect(){
		global $post, $page;
		if ($post->post_type == 'page') {
			$pt = new Page_columnist_page_transition($this, $post->ID);
			if (($pt->transition == $this->page_default_trans) && $page) {
				wp_redirect(get_permalink($post->ID));
				exit();
			}
		}
	}
	
}

//nothing more remains to do as to create an instance of the plugin itself :-)
$page_columnist_plug = new Plugin_page_columnist();

?>